Re: [PATCH/RFCv3 1/2] git-rebase -i: add command drop to remove a commit

2015-06-02 Thread Matthieu Moy
Galan Rémi remi.galan-alfo...@ensimag.grenoble-inp.fr writes:

 +test_expect_success 'drop' '

Please, be more descriptive in the first argument of
test_expect_success. It's usually a good thing to say not only what the
test stresses but also what the expected behavior is.

test_expect_success 'drop actually drops the lines' '
...
'

?

-- 
Matthieu Moy
http://www-verimag.imag.fr/~moy/
--
To unsubscribe from this list: send the line unsubscribe git in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Re: [PATCH/RFCv3 1/2] git-rebase -i: add command drop to remove a commit

2015-06-02 Thread Remi Galan Alfonso
Matthieu Moy matthieu@grenoble-inp.fr : writes
  +test_expect_success 'drop' '
 
 Please, be more descriptive in the first argument of
 test_expect_success. It's usually a good thing to say not only what the
 test stresses but also what the expected behavior is.
 
 test_expect_success 'drop actually drops the lines' '

For this one I've based myself on the first argument of some other
tests that tests commands for git rebase -i :
 t3404-rebase-interactive.sh:240
 test_expect_success 'squash' '
 t3404-rebase-interactive.sh:679
 test_expect_success 'reword' '

Rémi
--
To unsubscribe from this list: send the line unsubscribe git in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


[PATCH/RFCv3 1/2] git-rebase -i: add command drop to remove a commit

2015-06-02 Thread Galan Rémi
Instead of removing a line to remove the commit, you can use the
command drop (just like pick or edit). It has the same effect as
deleting the line (removing the commit) except that you keep a visual
trace of your actions, allowing a better control and reducing the
possibility of removing a commit by mistake.

Signed-off-by: Galan Rémi remi.galan-alfo...@ensimag.grenoble-inp.fr
---
 Documentation/git-rebase.txt  |  3 +++
 git-rebase--interactive.sh| 18 ++
 t/lib-rebase.sh   |  4 ++--
 t/t3404-rebase-interactive.sh | 10 ++
 4 files changed, 33 insertions(+), 2 deletions(-)

diff --git a/Documentation/git-rebase.txt b/Documentation/git-rebase.txt
index 1d01baa..9cf3760 100644
--- a/Documentation/git-rebase.txt
+++ b/Documentation/git-rebase.txt
@@ -514,6 +514,9 @@ rebasing.
 If you just want to edit the commit message for a commit, replace the
 command pick with the command reword.
 
+To drop a commit, replace the command pick with drop, or just
+delete its line.
+
 If you want to fold two or more commits into one, replace the command
 pick for the second and subsequent commits with squash or fixup.
 If the commits had different authors, the folded commit will be
diff --git a/git-rebase--interactive.sh b/git-rebase--interactive.sh
index dc3133f..869cc60 100644
--- a/git-rebase--interactive.sh
+++ b/git-rebase--interactive.sh
@@ -152,6 +152,7 @@ Commands:
  s, squash = use commit, but meld into previous commit
  f, fixup = like squash, but discard this commit's log message
  x, exec = run command (the rest of the line) using shell
+ d, drop = remove commit
 
 These lines can be re-ordered; they are executed from top to bottom.
 
@@ -508,6 +509,23 @@ do_next () {
$comment_char*|''|noop)
mark_action_done
;;
+   drop|d)
+   if test -z $sha1
+   then
+   warn Missing SHA-1 in 'drop' command.
+   die Please fix this using 'git rebase --edit-todo'.
+   fi
+
+   sha1_verif=$(git rev-parse --verify --quiet $sha1^{commit})
+   if test -z $sha1_verif
+   then
+   warn '$sha1' is not a SHA-1 or does not represent \
+   a commit in 'drop' command.
+   die Please fix this using 'git rebase --edit-todo'.
+   fi
+
+   mark_action_done
+   ;;
pick|p)
comment_for_reflog pick
 
diff --git a/t/t3404-rebase-interactive.sh b/t/t3404-rebase-interactive.sh
index ac429a0..8960083 100755
--- a/t/t3404-rebase-interactive.sh
+++ b/t/t3404-rebase-interactive.sh
@@ -1102,4 +1102,14 @@ test_expect_success 'rebase -i commits that overwrite 
untracked files (no ff)' '
test $(git cat-file commit HEAD | sed -ne \$p) = I
 '
 
+test_expect_success 'drop' '
+   test_when_finished git checkout master 
+   git checkout -b dropBranchTest master 
+   set_fake_editor 
+   FAKE_LINES=1 drop 2 3 drop 4 5 git rebase -i --root 
+   test E = $(git cat-file commit HEAD | sed -ne \$p) 
+   test C = $(git cat-file commit HEAD^ | sed -ne \$p) 
+   test A = $(git cat-file commit HEAD^^ | sed -ne \$p)
+'
+
 test_done
diff --git a/t/lib-rebase.sh b/t/lib-rebase.sh
index 6bd2522..fdbc900 100644
--- a/t/lib-rebase.sh
+++ b/t/lib-rebase.sh
@@ -14,7 +14,7 @@
 #   specified line.
 #
 #   cmd lineno -- add a line with the specified command
 #   (squash, fixup, edit, or reword) and the SHA1 taken
 #   from the specified line.
 #
 #   exec_cmd_with_args -- add an exec cmd with args line.
@@ -46,7 +46,7 @@ set_fake_editor () {
action=pick
for line in $FAKE_LINES; do
case $line in
-   squash|fixup|edit|reword)
+   squash|fixup|edit|reword|drop)
@@ -14,7 +14,7 @@
 #
 #   cmd lineno -- add a line with the specified command
-#   (squash, fixup, edit, or reword) and the SHA1 taken
+#   (squash, fixup, edit, reword or drop) and the SHA1 taken
 #   from the specified line.
 #
action=$line;;
exec*)
echo $line | sed 's/_/ /g'  $1;;
-- 
2.4.1.411.g9c4ad60

--
To unsubscribe from this list: send the line unsubscribe git in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html